@@ -13,7 +13,7 @@ JSON::Name - Provide a trait (and Attribute role) for JSON Marshal/Unmarshal whe
 use JSON::Name;
 
 class MyClass {
-	# The attribute meta object will have the role JSON::Name::NamedAttribute
+   # The attribute meta object will have the role JSON::Name::NamedAttribute
    # applied and "666.evil.name" will be stored in it's json-name attribute
    has $.nice-name is json-name('666.evil.name');
 
@@ -38,7 +38,7 @@ Of course it could be used in other modules for a similar purpose.
 
 
 
-module JSON::Name:ver<v0.0.1>:auth<github:jonathanstowe> {
+module JSON::Name:ver<0.0.3>:auth<github:jonathanstowe>:api<1.0> {
     role NamedAttribute {
         has Str $.json-name is rw;
     }
